==> haskell-concise-0.1.0.1-615-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-4yFOiLkGxLIJ0KhGAKynTu
key:                  concise-0.1.0.1-4yFOiLkGxLIJ0KhGAKynTu
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  c2fc3d7c72db2005e60aed3ae8a7afb0
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-4yFOiLkGxLIJ0KhGAKynTu
depends:
    base-4.17.2.1 bytestring-0.11.5.3 lens-5.3.1-9oQplfPnoWr2g52V8zm4go
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concise-0.1.0.1-616-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-Bz6ZYvwiau7w7dTKnYLH1
key:                  concise-0.1.0.1-Bz6ZYvwiau7w7dTKnYLH1
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  bf7ba042a1901050b983b6d86d0ac826
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-Bz6ZYvwiau7w7dTKnYLH1
depends:
    base-4.17.2.1 bytestring-0.11.5.3 lens-5.3.1-6s7OGBiqW0t1WJAI91dKgc
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
